@@ -28,14 +28,21 @@ class CustomConnection:
 
     async def _notify_package(self, p: Package):
         # TODO Make sure we aren't throwing any important data away
-        if p.command not in [1, 3, 4, 10]:
-            # print("Unexpected command: " + str(p))
-            pass
+        # if p.command not in [1, 3, 4, 10, 23]:
+        #    print("Unexpected command: " + str(p))
+        #    pass
 
-        if p.command != 4:
+        if p.command not in [4, 23]:
             return
 
         for o in self.api.objects:
+            # Only allow the command 23 on a Sif
+            if p.source == o.address and isinstance(o, IngSif):
+                print("SIF", o.components[0].id, p)
+
+            if p.command == 23 and not isinstance(o, IngSif):
+                return
+
             if await o.update_state(p):
                 for c in o.components:
                     try:
@@ -61,28 +68,36 @@ class CustomConnection:
 
         # TODO Launch binary server
 
-        self._is_closed = False
-        if self._ws_resp is not None:
-            await self._ws_resp.close()
+        while True:
+            try:
+                self._is_closed = False
+                if self._ws_resp is not None:
+                    await self._ws_resp.close()
 
-        self._ws_sess = aiohttp.ClientSession()
-        self._ws_resp = await self._ws_sess.ws_connect("ws://127.0.0.1:39812")
+                self._ws_sess = aiohttp.ClientSession()
+                self._ws_resp = await self._ws_sess.ws_connect("ws://127.0.0.1:39812")
 
-        await self._ws_resp.send_json(
-            {'just_login': just_login, 'hass_integration': hass_integration, **self._login_dict})
+                login_body = {'just_login': just_login, 'hass_integration': hass_integration, **self._login_dict}
+                await self._ws_resp.send_json(login_body)
 
-        res: dict = await self._ws_resp.receive_json(timeout=180)  # Max 3 mins
+                res: dict = await self._ws_resp.receive_json(timeout=300)  # Max 5 mins
 
-        if res.get("kind") != "login":
-            print("Invalid login kind: " + str(res))
-            return None
+                if res.get("kind") != "login":
+                    print("Invalid login kind: " + str(res))
+                    return None
 
-        return res
+                return res
+            except Exception as e:
+                if just_login:
+                    return None
+
+                # If we aren't doing the first login, retry this
+                await asyncio.sleep(10)
 
     async def conn_loop(self):
         while not self._is_closed:
             try:
-                res: dict = await self._ws_resp.receive_json(timeout=180)  # Max 3 mins
+                res: dict = await self._ws_resp.receive_json(timeout=300)  # Max 5 mins
                 if res.get("kind") == "raw":
                     await self._notify_package(
                         Package(res["source"], res["target"], res["command"], res["data1"], res["data2"]))
@@ -93,8 +108,8 @@ class CustomConnection:
                 else:
                     print("Invalid package kind: " + str(res))
 
-            except (aiohttp.ClientError, TypeError) as e:
-                print("Connection has been closed: " + str(e))
+            except (aiohttp.ClientError, TypeError, asyncio.TimeoutError) as e:
+                print("Connection error, closed: ", repr(e), e)
                 if not self._is_closed:
                     self._is_closed = True
                     if self._ws_resp is not None:
