@@ -1,7 +1,7 @@
 import asyncio
+import inspect
 from enum import Enum
 from typing import Callable, List, TYPE_CHECKING, Dict, Any
-import inspect
 
 if TYPE_CHECKING:
     from .api import IngeniumAPI
@@ -174,6 +174,7 @@ class IngComponent:
             except BaseException as e:
                 print("Exception {} at {}".format(e, inspect.getsource(cb)))
 
+
 class IngObject:
     api: 'IngeniumAPI'
     is_knx: bool
@@ -377,12 +378,12 @@ class IngActuator(IngObject):
                 old_value = self.active_power_bits[0]
                 self.active_power_bits[0] = p.data2
                 return self.active_power_bits[0] != old_value
-            
+
             elif p.data1 == 89:
                 old_value = self.active_power_bits[1]
                 self.active_power_bits[1] = p.data2
                 if self.active_power_bits[0] != -1:
-                    self.active_power = (self.active_power_bits[0] << 8)  + self.active_power_bits[1]
+                    self.active_power = (self.active_power_bits[0] << 8) + self.active_power_bits[1]
                 return self.active_power_bits[1] != old_value
 
         return False
@@ -512,6 +513,8 @@ class IngSif(IngObject):
         self.values_255 = [255, 255, 255, 255, 255]
         self.values_len = 5
 
+        self.bat_baja = False
+
     async def read_state(self):
         self.updating_modes = SIF_AVAILABLE_MODES.copy()
         await self._read()
@@ -548,6 +551,11 @@ class IngSif(IngObject):
         self.values[p.data1] = convert_sif_value(p.data2, p.data1)
         self.values_255[p.data1] = p.data2
 
+        if p.command == 23:
+            old_bat_baja = self.bat_baja
+            self.bat_baja = True
+            return not old_bat_baja
+
         return self.values[p.data1] != old_value
 
     def get_available(self, mode: int):
